<?php
/**
 * A command for logout
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class WebLogoutCommand extends BaseCommand implements Commandable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @param	$resolverInstance	An instance of a command resolver class
	 * @return	$commandInstance	An instance a prepared command class
	 */
	public static final function createWebLogoutCommand (CommandResolver $resolverInstance) {
		// Get new instance
		$commandInstance = new WebLogoutCommand();

		// Set the application instance
		$commandInstance->setResolverInstance($resolverInstance);

		// Return the prepared instance
		return $commandInstance;
	}

	/**
	 * Executes the given command with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get an auth instance for checking and updating the auth cookies
		$authInstance = ObjectFactory::createObjectByConfiguredName('auth_method_class', array($responseInstance));

		// Set request instance
		$authInstance->setRequestInstance($requestInstance);

		// Destroy the auth data
		$authInstance->destroyAuthData();

		// Redirect to "logout done" page
		$responseInstance->redirectToConfiguredUrl('logout_done');

		// Exit here
		exit();
	}

	/**
	 * Adds extra filters to the given controller instance
	 *
	 * @param	$controllerInstance		A controller instance
	 * @param	$requestInstance		An instance of a class with an Requestable interface
	 * @return	void
	 */
	public function addExtraFilters (Controller $controllerInstance, Requestable $requestInstance) {
		// Empty for now
	}
}

// [EOF]
?>
